libusb_config_descriptor class

\ingroup libusb_desc A structure representing the standard USB configuration descriptor. This descriptor is documented in section 9.6.3 of the USB 3.0 specification. All multiple-byte fields are represented in host-endian format.

Inheritance
Implemented types
Available extensions

Constructors

libusb_config_descriptor()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bConfigurationValue ↔ int
Identifier value for this configuration
getter/setter pair
bDescriptorType ↔ int
Descriptor type. Will have value \ref libusb_descriptor_type::LIBUSB_DT_CONFIG LIBUSB_DT_CONFIG in this context.
getter/setter pair
bLength ↔ int
Size of this descriptor (in bytes)
getter/setter pair
bmAttributes ↔ int
Configuration characteristics
getter/setter pair
bNumInterfaces ↔ int
Number of interfaces supported by this configuration
getter/setter pair
extra ↔ Pointer<Uint8>
Extra descriptors. If libusb encounters unknown configuration descriptors, it will store them here, should you wish to parse them.
getter/setter pair
extra_length ↔ int
Length of the extra descriptors, in bytes. Must be non-negative.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iConfiguration ↔ int
Index of string descriptor describing this configuration
getter/setter pair
interface_1 ↔ Pointer<libusb_interface>
Array of interfaces supported by this configuration. The length of this array is determined by the bNumInterfaces field.
getter/setter pair
MaxPower ↔ int
Maximum power consumption of the USB device from this bus in this configuration when the device is fully operation. Expressed in units of 2 mA when the device is operating in high-speed mode and in units of 8 mA when the device is operating in super-speed mode.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wTotalLength ↔ int
Total length of data returned for this configuration
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited