libusb_device_descriptor class

\ingroup libusb_desc A structure representing the standard USB device descriptor. This descriptor is documented in section 9.6.1 of the USB 3.0 specification. All multiple-byte fields are represented in host-endian format.

Inheritance
Implemented types
Available extensions

Constructors

libusb_device_descriptor()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bcdDevice ↔ int
Device release number in binary-coded decimal
getter/setter pair
bcdUSB ↔ int
USB specification release number in binary-coded decimal. A value of 0x0200 indicates USB 2.0, 0x0110 indicates USB 1.1, etc.
getter/setter pair
bDescriptorType ↔ int
Descriptor type. Will have value \ref libusb_descriptor_type::LIBUSB_DT_DEVICE LIBUSB_DT_DEVICE in this context.
getter/setter pair
bDeviceClass ↔ int
USB-IF class code for the device. See \ref libusb_class_code.
getter/setter pair
bDeviceProtocol ↔ int
USB-IF protocol code for the device, qualified by the bDeviceClass and bDeviceSubClass values
getter/setter pair
bDeviceSubClass ↔ int
USB-IF subclass code for the device, qualified by the bDeviceClass value
getter/setter pair
bLength ↔ int
Size of this descriptor (in bytes)
getter/setter pair
bMaxPacketSize0 ↔ int
Maximum packet size for endpoint 0
getter/setter pair
bNumConfigurations ↔ int
Number of possible configurations
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idProduct ↔ int
USB-IF product ID
getter/setter pair
idVendor ↔ int
USB-IF vendor ID
getter/setter pair
iManufacturer ↔ int
Index of string descriptor describing manufacturer
getter/setter pair
iProduct ↔ int
Index of string descriptor describing product
getter/setter pair
iSerialNumber ↔ int
Index of string descriptor containing device serial number
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited