libusb_interface class

\ingroup libusb_desc A collection of alternate settings for a particular USB interface.

Inheritance
Implemented types
Available extensions

Constructors

libusb_interface()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
altsetting ↔ Pointer<libusb_interface_descriptor>
Array of interface descriptors. The length of this array is determined by the num_altsetting field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
num_altsetting ↔ int
The number of alternate settings that belong to this interface. Must be non-negative.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited