libusb_iso_packet_descriptor class

\ingroup libusb_asyncio Isochronous packet descriptor.

Inheritance
Implemented types
Available extensions

Properties

actual_length ↔ int
Amount of data that was actually transferred
getter/setter pair
address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
Length of data to request in this packet
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
Status code for this packet
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited